import Logger from "@home-gallery/logger";
const log = Logger("index.filter.limit");
const getLimitValues = (addLimits) => {
  const limits = addLimits.split(",");
  return {
    initial: +limits[0] || 200,
    offset: +limits[1] || 500,
    factor: Math.max(1, +limits[2] || 1) - 1,
    max: +limits[3] || 8e3
  };
};
function getNewFileLimit(entryCount, addLimits) {
  const { initial, offset, factor, max } = getLimitValues(addLimits);
  if (entryCount == 0) {
    return initial;
  } else {
    return Math.min(max, Math.max(offset, Math.floor(entryCount * factor)));
  }
}
function createLimitFilter(entryCount, filename2Entry, addLimits, filter) {
  if (!addLimits) {
    return filter;
  }
  const fileLimit = getNewFileLimit(entryCount, addLimits);
  log.info(`Index has ${entryCount} entries. Set index limit to max ${fileLimit} new entries`);
  let count = 0;
  const limitFilter = (filename, stat) => {
    const result = filter(filename, stat);
    if (!result) {
      return result;
    } else if (filename2Entry[filename]) {
      return true;
    }
    count++;
    if (count == fileLimit) {
      log.info(`Index limit of ${fileLimit} exceeded. No more new files are added to the file index.`);
    }
    return count <= fileLimit;
  };
  limitFilter.limitExceeded = () => count >= fileLimit;
  return limitFilter;
}
export {
  createLimitFilter,
  getNewFileLimit
};
//# sourceMappingURL=limit-filter.js.map
