import path from "path";
const getIndexName = (filename) => path.basename(filename).replace(/\.[^.]+$/, "");
const unitToFactor = {
  "B": 1,
  "K": 1 << 10,
  "M": 1 << 20,
  "G": 1 << 30,
  "T": (1 << 30) * (1 << 10),
  "P": (1 << 30) * (1 << 20)
};
const parseFilesize = (filesize) => {
  const match = filesize.toUpperCase().match(/^(\d+(\.\d+)?)(([PTGMK])([B])?|[B])?$/);
  if (!match) {
    return false;
  }
  const [_, size, _1, byte, unit] = match;
  const factor = unitToFactor[unit || byte || "B"];
  return parseFloat(size) * factor;
};
const byDirDescFileAsc = (a, b) => {
  const aParts = a.filename.split(path.sep);
  const bParts = b.filename.split(path.sep);
  const minLen = Math.min(aParts.length, bParts.length);
  for (let i = 0; i < minLen; i++) {
    const aIsDir = i < aParts.length - 1 || a.isDirectory;
    const bIsDir = i < bParts.length - 1 || b.isDirectory;
    if (aParts[i] == bParts[i] && aIsDir && bIsDir) {
      continue;
    }
    if (aIsDir === bIsDir) {
      const rev = aIsDir ? 1 : -1;
      return aParts[i] < bParts[i] ? rev : -1 * rev;
    } else {
      return aIsDir ? -1 : 1;
    }
  }
  return aParts.length < bParts.length ? -1 : 1;
};
export {
  byDirDescFileAsc,
  getIndexName,
  parseFilesize
};
//# sourceMappingURL=utils.js.map
