import Logger from "@home-gallery/logger";
import { PluginManager } from "./manager/manager.js";
import { Storage } from "./extractor/storage.js";
import { ExtractorStreamFactory } from "./extractor/extractorStreamFactory.js";
import { createDatabaseMapperStream as createDatabaseMapperFactory } from "./database/databaseMapperStreamFactory.js";
const log = Logger("pluginManager.factory");
async function createPluginManager(config, context = { type: "serverContext", plugin: {} }) {
  const t0 = Date.now();
  const manager = new PluginManager(config, context);
  await manager.loadPlugins();
  const plugins = manager.getPlugins();
  log.info(t0, `Initialized plugin manager with ${plugins.length} plugins`);
  return manager;
}
async function createExtractorStreams(config) {
  const context = {
    type: "extractorContext",
    plugin: {}
  };
  const manager = await createPluginManager(config, context);
  const storage = new Storage(config?.storage?.dir || ".");
  const streamFactory = new ExtractorStreamFactory(manager, storage, manager.getExtensions());
  return streamFactory.getExtractorStreams();
}
async function createDatabaseMapperStream(config) {
  const context = {
    type: "databaseMapperContext",
    plugin: {}
  };
  const manager = await createPluginManager(config, context);
  const updated = config.database.updated || new Date().toISOString();
  return createDatabaseMapperFactory(manager.getExtensions(), manager.getConfig(), updated);
}
export {
  createDatabaseMapperStream,
  createExtractorStreams,
  createPluginManager
};
//# sourceMappingURL=factory.js.map
