const PATH_PATTERN = /([^'.]+|'[^']+')\.?/g;
function getPath(o, path) {
  const parts = [];
  for (const match of path.matchAll(PATH_PATTERN)) {
    const [_, name] = match;
    const part = name.startsWith("'") ? name.substring(1, name.length - 1) : name;
    parts.push(part);
  }
  let result = o;
  let i = 0;
  while (result && i < parts.length) {
    if (typeof result == "object") {
      result = result[parts[i++]];
    } else {
      result = void 0;
    }
  }
  return result;
}
const nodeEntryPaths = [
  "exports",
  "exports.module",
  "exports.node",
  "exports.node.module",
  "exports.'.'.module",
  "exports.'.'.node",
  "exports.'.'.node.module",
  "main"
];
const browserEntryPaths = [
  "exports.browser",
  "exports.'.'.browser",
  "browser"
];
function resolvePackageEntry(pkg) {
  for (let path of nodeEntryPaths) {
    const entry = getPath(pkg, path);
    if (typeof entry == "string") {
      return entry;
    }
  }
}
function resolveBrowserEntry(pkg) {
  for (let path of browserEntryPaths) {
    const entry = getPath(pkg, path);
    if (typeof entry == "string") {
      return entry;
    }
  }
}
export {
  resolveBrowserEntry,
  resolvePackageEntry
};
//# sourceMappingURL=pkg.js.map
